==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/SimpleHandler.h <==
// abstract class gnu.java.beans.decoder.SimpleHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractElementHandler

#include "gnu/java/beans/decoder/AbstractElementHandler.h"

#ifndef _JC_gnu_java_beans_decoder_SimpleHandler_H_
#define _JC_gnu_java_beans_decoder_SimpleHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_ObjectContext$object;
struct _jc_java_beans_ExceptionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	_jc_gnu_java_beans_decoder_SimpleHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_SimpleHandler$refs	_jc_gnu_java_beans_decoder_SimpleHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_SimpleHandler$nonrefs	_jc_gnu_java_beans_decoder_SimpleHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_SimpleHandler$object	_jc_gnu_java_beans_decoder_SimpleHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_SimpleHandler$vmethods	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_SimpleHandler$vtable	_jc_gnu_java_beans_decoder_SimpleHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_SimpleHandler$vtype	_jc_gnu_java_beans_decoder_SimpleHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_SimpleHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_object *);

// Virtual methods
extern void _jc_gnu_java_beans_decoder_SimpleHandler$method$endElement$56f788a75f206f8d(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_SimpleHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_java_beans_decoder_SimpleHandler$method$startElement$c132d696183c1bce(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_SimpleHandler$method_info$endElement$56f788a75f206f8d;
extern _jc_method _jc_gnu_java_beans_decoder_SimpleHandler$method_info$parse$d4a2df662e34a121;
extern _jc_method _jc_gnu_java_beans_decoder_SimpleHandler$method_info$startElement$c132d696183c1bce;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_SimpleHandler$vmethods {
	void	(*endElement$56f788a75f206f8d)(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*startElement$c132d696183c1bce)(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_SimpleHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_SimpleHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_SimpleHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs {
	struct _jc_gnu_java_beans_decoder_ObjectContext$object	*context;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_SimpleHandler$refs {
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_SimpleHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_SimpleHandler$object {
	_jc_gnu_java_beans_decoder_SimpleHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_SimpleHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_SimpleHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_SimpleHandler$vtype _jc_gnu_java_beans_decoder_SimpleHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_SimpleHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_SimpleHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_SimpleHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/SimpleHandler.h <==
// abstract class gnu.java.beans.decoder.SimpleHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractElementHandler

#include "gnu/java/beans/decoder/AbstractElementHandler.h"

#ifndef _JC_gnu_java_beans_decoder_SimpleHandler_H_
#define _JC_gnu_java_beans_decoder_SimpleHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_ObjectContext$object;
struct _jc_java_beans_ExceptionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	_jc_gnu_java_beans_decoder_SimpleHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_SimpleHandler$refs	_jc_gnu_java_beans_decoder_SimpleHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_SimpleHandler$nonrefs	_jc_gnu_java_beans_decoder_SimpleHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_SimpleHandler$object	_jc_gnu_java_beans_decoder_SimpleHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_SimpleHandler$vmethods	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_SimpleHandler$vtable	_jc_gnu_java_beans_decoder_SimpleHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_SimpleHandler$vtype	_jc_gnu_java_beans_decoder_SimpleHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_SimpleHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_beans_decoder_SimpleHandler$method$endElement$56f788a75f206f8d(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_SimpleHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_beans_decoder_SimpleHandler$method$startElement$c132d696183c1bce(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_SimpleHandler$method_info$endElement$56f788a75f206f8d;
extern _jc_method _jc_gnu_java_beans_decoder_SimpleHandler$method_info$parse$d4a2df662e34a121;
extern _jc_method _jc_gnu_java_beans_decoder_SimpleHandler$method_info$startElement$c132d696183c1bce;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_SimpleHandler$vmethods {
	void	(*endElement$56f788a75f206f8d)(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*startElement$c132d696183c1bce)(_jc_env *, struct _jc_gnu_java_beans_decoder_SimpleHandler$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_SimpleHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_SimpleHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_SimpleHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs {
	struct _jc_gnu_java_beans_decoder_ObjectContext$object	*context;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_SimpleHandler$refs {
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_SimpleHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_SimpleHandler$object {
	_jc_gnu_java_beans_decoder_SimpleHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_SimpleHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_SimpleHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_SimpleHandler$vtype _jc_gnu_java_beans_decoder_SimpleHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_SimpleHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_SimpleHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_SimpleHandler_H_ */
